@@ -118,8 +118,54 @@ class SslClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def CheckCertificateDomainVerification(self, request):
+        """检查证书域名验证
+
+        :param request: Request instance for CheckCertificateDomainVerification.
+        :type request: :class:`tencentcloud.ssl.v20191205.models.CheckCertificateDomainVerificationRequest`
+        :rtype: :class:`tencentcloud.ssl.v20191205.models.CheckCertificateDomainVerificationResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CheckCertificateDomainVerification", params, headers=headers)
+            response = json.loads(body)
+            model = models.CheckCertificateDomainVerificationResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def CheckCertificateExist(self, request):
+        """根据证书内容检测当前账号下是否存在一致的证书， 存在则返回证书ID， 不存在则返回空
+
+        :param request: Request instance for CheckCertificateExist.
+        :type request: :class:`tencentcloud.ssl.v20191205.models.CheckCertificateExistRequest`
+        :rtype: :class:`tencentcloud.ssl.v20191205.models.CheckCertificateExistResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CheckCertificateExist", params, headers=headers)
+            response = json.loads(body)
+            model = models.CheckCertificateExistResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def CommitCertificateInformation(self, request):
-        """提交证书订单。
+        """提交证书订单到CA机构。
 
         :param request: Request instance for CommitCertificateInformation.
         :type request: :class:`tencentcloud.ssl.v20191205.models.CommitCertificateInformationRequest`
@@ -142,7 +188,7 @@ class SslClient(AbstractClient):
 
 
     def CompleteCertificate(self, request):
-        """本接口（CompleteCertificate）用于主动触发证书验证。仅非DNSPod和Wotrus品牌证书支持使用此接口。
+        """本接口（CompleteCertificate）用于主动触发证书验证。DNSPod和Wotrus品牌的证书不支持使用此接口。
 
         :param request: Request instance for CompleteCertificate.
         :type request: :class:`tencentcloud.ssl.v20191205.models.CompleteCertificateRequest`
@@ -188,7 +234,7 @@ class SslClient(AbstractClient):
 
 
     def CreateCertificateBindResourceSyncTask(self, request):
-        """创建证书绑定关联云资源异步任务， 该接口用于查询证书关联云资源。 若证书ID已存在查询云资源任务，则结果返回该任务ID。关联云资源类型，支持以下云资源：clb、cdn、waf、live、vod、ddos、tke、apigateway、tcb、teo（edgeOne）。查询关联云资源结果使用DescribeCertificateBindResourceTaskResult接口
+        """创建证书绑定关联云资源异步任务， 该接口用于查询证书关联云资源。 若证书ID已存在查询云资源任务，则结果返回该任务ID。关联云资源类型，支持以下云资源：clb、cdn、waf、live、vod、ddos、tke、apigateway、tcb、teo（edgeOne）、cos。查询关联云资源结果使用DescribeCertificateBindResourceTaskResult接口
 
         :param request: Request instance for CreateCertificateBindResourceSyncTask.
         :type request: :class:`tencentcloud.ssl.v20191205.models.CreateCertificateBindResourceSyncTaskRequest`
@@ -303,7 +349,14 @@ class SslClient(AbstractClient):
 
 
     def DeployCertificateInstance(self, request):
-        """证书部署到云资源实例列表
+        """证书部署到云资源实例列表，本接口只会创建部署任务， 部署任务结果可通过DescribeHostDeployRecordDetail查询。本接口创建部署任务时，会校验证书和部署实例的匹配关系，存在不匹配的则会创建部署任务失败。以下为匹配关系校验规则：
+        - 若待部署的证书和传入实例域名的当前绑定的证书一致， 则不会创建成功
+        - 若待部署的证书和传入域名不匹配， 则不会创建成功
+        - 若部署clb实例时， 7层监听器下无规则，则不会创建成功
+        - 若部署clb实例时， 7层监听器未开启SNI，该监听器下存在任一域名和证书不匹配， 则不会创建成功
+        - 若部署clb实例时，监听器规则为正则表示式， 则不会创建成功
+
+        <dx-alert infotype="explain" title="">一个证书ID，相同的资源类型，只能创建一个部署任务，必须等部署任务执行完成，才能创建新的部署任务</dx-alert>
 
         :param request: Request instance for DeployCertificateInstance.
         :type request: :class:`tencentcloud.ssl.v20191205.models.DeployCertificateInstanceRequest`
@@ -395,7 +448,7 @@ class SslClient(AbstractClient):
 
 
     def DescribeCertificateBindResourceTaskDetail(self, request):
-        """查询CreateCertificateBindResourceSyncTask任务结果， 返回证书关联云资源异步任务结果， 支持以下云资源：clb、cdn、waf、live、vod、ddos、tke、apigateway、tcb、teo（edgeOne）
+        """查询CreateCertificateBindResourceSyncTask任务结果， 返回证书关联云资源异步任务结果， 支持以下云资源：clb、cdn、waf、live、vod、ddos、tke、apigateway、tcb、teo（edgeOne）、cos
 
         :param request: Request instance for DescribeCertificateBindResourceTaskDetail.
         :type request: :class:`tencentcloud.ssl.v20191205.models.DescribeCertificateBindResourceTaskDetailRequest`
@@ -418,7 +471,7 @@ class SslClient(AbstractClient):
 
 
     def DescribeCertificateBindResourceTaskResult(self, request):
-        """查询CreateCertificateBindResourceSyncTask任务结果， 返回证书关联云资源异步任务结果， 支持以下云资源：clb、cdn、waf、live、vod、ddos、tke、apigateway、tcb、teo（edgeOne）
+        """查询CreateCertificateBindResourceSyncTask任务结果， 返回证书关联云资源异步任务结果， 支持以下云资源：clb、cdn、waf、live、vod、ddos、tke、apigateway、tcb、teo（edgeOne）、cos
 
         :param request: Request instance for DescribeCertificateBindResourceTaskResult.
         :type request: :class:`tencentcloud.ssl.v20191205.models.DescribeCertificateBindResourceTaskResultRequest`
